@@ -234,12 +234,15 @@ class Crp:
 
         df_matrix = grp.agg(grp_dict).rename(columns={'id': 'num_orders', 'totalprice': 'TotalSpent'})
         # Create only date column
+        print(df_matrix.shape)
         df_matrix['order_date'] = df_matrix['createdat'].dt.date
 
         # Recency Feature
         df_matrix = self.getRecency(df_matrix, dateFlag_sep)
+        print(df_matrix.shape)
         # Different Last orders parameters feature ( Discount value, weight )
         df_matrix = self.getLastOrderparams(df_matrix, train_df, dateFlag_sep, date_flag_min, customer_name, sq_pass)
+        print(df_matrix.shape)
         df_matrix = self.getTotalSpentLMonth(train_df, dateFlag_sep, df_matrix, lastTimeflagParam)
 
         # Turn the separators into strings for the snowflake query
@@ -251,7 +254,7 @@ class Crp:
         orders_param.columns = orders_param.columns.str.lower()
 
         output = pd.merge(df_matrix, orders_param, how='left', on='customerid')
-
+        print(output.shape)
         output = output.fillna(999)
 
         return output
